//-----------------------------------------------------------------------
//  Java Indexed Serialization Package
//  ----------------------------------
//  FindStateByZip.java
//-----------------------------------------------------------------------
//
//  COPYRIGHT NOTICE, DISCLAIMER, and LICENSE:
//  
//  If you modify this file, you may insert additional notices
//  immediately following this sentence.
//  
//  Copyright 1996-2002 Scott Robert Ladd.
//  All rights reserved, except as noted herein.
//  
//  This computer program source file is supplied "AS IS". Scott Robert
//  Ladd (hereinafter referred to as "Author") disclaims all warranties,
//  expressed or implied, including, without limitation, the warranties
//  of merchantability and of fitness for any purpose. The Author
//  assumes no liability for direct, indirect, incidental, special,
//  exemplary, or consequential damages, which may result from the use
//  of this software, even if advised of the possibility of such damage.
//  
//  The Author hereby grants anyone permission to use, copy, modify, and
//  distribute this source code, or portions hereof, for any purpose,
//  without fee, subject to the following restrictions:
//  
//      1. The origin of this source code must not be misrepresented.
//  
//      2. Altered versions must be plainly marked as such and must not
//         be misrepresented as being the original source.
//  
//      3. This Copyright notice may not be removed or altered from any
//         source or altered source distribution.
//  
//  The Author specifically permits (without fee) and encourages the use
//  of this source code for entertainment, education, or decoration. If
//  you use this source code in a product, acknowledgment is not required
//  but would be appreciated.
//  
//  Acknowledgement:
//      This license is based on the wonderful simple license that
//      accompanies libpng.
//
//-----------------------------------------------------------------------
//  For more information on this software package, please visit
//  Scott's web site, Coyote Gulch Productions, at:
//
//      http://www.coyotegulch.com
//-----------------------------------------------------------------------

public class FindStateByZip
{
    private static class ZIPRange
    {
        String m_state;
        int    m_loZIP;
        int    m_hiZIP;
    
        ZIPRange(String state, int loZIP, int hiZIP)
        {
            m_state = state;
            m_loZIP = loZIP;
            m_hiZIP = hiZIP;
        }
    }

    private static final ZIPRange [] s_range =
    {
        new ZIPRange("NH",  210,  215),
        new ZIPRange("NY",  501,  501),
        new ZIPRange("NY",  544,  544),
        new ZIPRange("PR",  601,  795),
        new ZIPRange("VI",  801,  851),
        new ZIPRange("PR",  901,  988),
        new ZIPRange("MA", 1001, 2791),
        new ZIPRange("RI", 2801, 2940),
        new ZIPRange("NH", 3031, 3897),
        new ZIPRange("ME", 3901, 4992),
        new ZIPRange("VT", 5001, 5495),
        new ZIPRange("MA", 5501, 5544),
        new ZIPRange("VT", 5601, 5907),
        new ZIPRange("CT", 6001, 6389),
        new ZIPRange("NY", 6390, 6390),
        new ZIPRange("CT", 6401, 6928),
        new ZIPRange("NJ", 7001, 8989),
        new ZIPRange("NY",10001,14975),
        new ZIPRange("PA",15001,19640),
        new ZIPRange("DE",19701,19980),
        new ZIPRange("DC",20001,20099),
        new ZIPRange("VA",20101,20199),
        new ZIPRange("DC",20201,20599),
        new ZIPRange("MD",20601,21930),
        new ZIPRange("VA",22002,24658),
        new ZIPRange("WV",24701,26886),
        new ZIPRange("NC",27006,28909),
        new ZIPRange("SC",29001,29945),
        new ZIPRange("GA",30002,31999),
        new ZIPRange("FL",32004,34997),
        new ZIPRange("AL",35004,36925),
        new ZIPRange("TN",37010,38589),
        new ZIPRange("MS",38601,39776),
        new ZIPRange("GA",39901,39901),
        new ZIPRange("KY",40003,42788),
        new ZIPRange("OH",43001,45999),
        new ZIPRange("IN",46001,47997),
        new ZIPRange("MI",48001,49971),
        new ZIPRange("IA",50001,52809),
        new ZIPRange("WI",53001,54990),
        new ZIPRange("MN",55001,56763),
        new ZIPRange("SD",57001,57799),
        new ZIPRange("ND",58001,58856),
        new ZIPRange("MT",59001,59937),
        new ZIPRange("IL",60001,62999),
        new ZIPRange("MO",63001,65899),
        new ZIPRange("KS",66002,67954),
        new ZIPRange("NE",68001,69367),
        new ZIPRange("LA",70001,71497),
        new ZIPRange("AR",71601,72959),
        new ZIPRange("OK",73001,73199),
        new ZIPRange("TX",73301,73344),
        new ZIPRange("OK",73401,74966),
        new ZIPRange("TX",75001,79999),
        new ZIPRange("CO",80001,81658),
        new ZIPRange("WY",82001,83128),
        new ZIPRange("ID",83201,83888),
        new ZIPRange("UT",84001,84791),
        new ZIPRange("AZ",85001,86556),
        new ZIPRange("NM",87001,88441),
        new ZIPRange("TX",88510,88595),
        new ZIPRange("NV",88901,89883),
        new ZIPRange("CA",90001,96162),
        new ZIPRange("AP",96201,96698),
        new ZIPRange("HI",96701,96797),
        new ZIPRange("AS",96799,96799),
        new ZIPRange("HI",96801,96898),
        new ZIPRange("GU",96910,96932),
        new ZIPRange("PW",96940,96940),
        new ZIPRange("FM",96941,96944),
        new ZIPRange("MP",96950,96952),
        new ZIPRange("MH",96960,96970),
        new ZIPRange("OR",97001,97920),
        new ZIPRange("WA",98001,99403),
        new ZIPRange("AK",99501,99950)
    };

    static String findState(int zip)
    {
        for (int i = 0; i < s_range.length; ++i)
        {
            if ((zip >= s_range[i].m_loZIP) && (zip <= s_range[i].m_hiZIP))
                return s_range[i].m_state;
        }

        return "??";
    }

}
